==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/scripts/zh.php <==
<?php

return [
    'Names' => [
        'Adlm' => '阿德拉姆文',
        'Afak' => '阿法卡文',
        'Aghb' => '高加索阿尔巴尼亚文',
        'Ahom' => 'Ahom',
        'Arab' => '阿拉伯文',
        'Aran' => '波斯体',
        'Armi' => '皇室亚拉姆文',
        'Armn' => '亚美尼亚文',
        'Avst' => '阿维斯陀文',
        'Bali' => '巴厘文',
        'Bamu' => '巴姆穆文',
        'Bass' => '巴萨文',
        'Batk' => '巴塔克文',
        'Beng' => '孟加拉文',
        'Bhks' => '拜克舒克文',
        'Blis' => '布列斯符号',
        'Bopo' => '汉语拼音',
        'Brah' => '婆罗米文字',
        'Brai' => '布莱叶盲文',
        'Bugi' => '布吉文',
        'Buhd' => '布希德文',
        'Cakm' => '查克马文',
        'Cans' => '加拿大土著统一音节',
        'Cari' => '卡里亚文',
        'Cham' => '占文',
        'Cher' => '切罗基文',
        'Chrs' => '花拉子模文',
        'Cirt' => '色斯文',
        'Copt' => '克普特文',
        'Cprt' => '塞浦路斯文',
        'Cyrl' => '西里尔文',
        'Cyrs' => '西里尔文字（古教会斯拉夫文的变体）',
        'Deva' => '天城文',
        'Diak' => '迪维西阿库鲁文',
        'Dogr' => '多格拉文',
        'Dsrt' => '德塞莱特文',
        'Dupl' => '杜普洛伊速记',
        'Egyd' => '后期埃及文',
        'Egyh' => '古埃及僧侣书写体',
        'Egyp' => '古埃及象形文',
        'Elba' => '爱尔巴桑文',
        'Elym' => '埃利迈文',
        'Ethi' => '埃塞俄比亚文',
        'Geok' => '格鲁吉亚文（教堂体）',
        'Geor' => '格鲁吉亚文',
        'Glag' => '格拉哥里文',
        'Gong' => '贡贾拉贡德文',
        'Gonm' => '马萨拉姆冈德文',
        'Goth' => '哥特文',
        'Gran' => '格兰塔文',
        'Grek' => '希腊文',
        'Gujr' => '古吉拉特文',
        'Guru' => '果鲁穆奇文',
        'Hanb' => '汉语注音',
        'Hang' => '谚文',
        'Hani' => '汉字',
        'Hano' => '汉奴罗文',
        'Hans' => '简体',
        'Hant' => '繁体',
        'Hatr' => '哈特兰文',
        'Hebr' => '希伯来文',
        'Hira' => '平假名',
        'Hluw' => '安那托利亚象形文字',
        'Hmng' => '杨松录苗文',
        'Hmnp' => '尼亚肯蒲丘苗文',
        'Hrkt' => '假名表',
        'Hung' => '古匈牙利文',
        'Inds' => '印度河文字',
        'Ital' => '古意大利文',
        'Jamo' => '韩文字母',
        'Java' => '爪哇文',
        'Jpan' => '日文',
        'Jurc' => '女真文',
        'Kali' => '克耶李文字',
        'Kana' => '片假名',
        'Khar' => '卡罗须提文',
        'Khmr' => '高棉文',
        'Khoj' => '克吉奇文字',
        'Kits' => '契丹小字',
        'Knda' => '卡纳达文',
        'Kore' => '韩文',
        'Kpel' => '克佩列文',
        'Kthi' => '凯提文',
        'Lana' => '兰拿文',
        'Laoo' => '老挝文',
        'Latf' => '拉丁文（哥特式字体变体）',
        'Latg' => '拉丁文（盖尔文变体）',
        'Latn' => '拉丁文',
        'Lepc' => '雷布查文',
        'Limb' => '林布文',
        'Lina' => '线形文字（A）',
        'Linb' => '线形文字（B）',
        'Lisu' => '傈僳文',
        'Loma' => '洛马文',
        'Lyci' => '利西亚文',
        'Lydi' => '吕底亚文',
        'Mahj' => '默哈金文',
        'Maka' => '望加锡文',
        'Mand' => '阿拉米文',
        'Mani' => '摩尼教文',
        'Marc' => '大玛尔文',
        'Maya' => '玛雅圣符文',
        'Medf' => '梅德法伊德林文',
        'Mend' => '门迪文',
        'Merc' => '麦罗埃草书',
        'Mero' => '麦若提克文',
        'Mlym' => '马拉雅拉姆文',
        'Modi' => '莫迪文',
        'Mong' => '蒙古文',
        'Moon' => '韩文语系',
        'Mroo' => '谬文',
        'Mtei' => '曼尼普尔文',
        'Mult' => '穆尔坦文',
        'Mymr' => '缅甸文',
        'Nand' => '楠迪梵文',
        'Narb' => '古北方阿拉伯文',
        'Nbat' => '纳巴泰文',
        'Newa' => '尼瓦文',
        'Nkgb' => '纳西格巴文',
        'Nkoo' => '西非书面文字（N’Ko）',
        'Nshu' => '女书',
        'Ogam' => '欧甘文',
        'Olck' => '桑塔利文',
        'Orkh' => '鄂尔浑文',
        'Orya' => '奥里亚文',
        'Osge' => '欧塞奇文',
        'Osma' => '奥斯曼亚文',
        'Palm' => '帕尔迈拉文',
        'Pauc' => '包金豪文',
        'Perm' => '古彼尔姆文',
        'Phag' => '八思巴文',
        'Phli' => '巴列维文碑铭体',
        'Phlp' => '巴列维文（圣诗体）',
        'Phlv' => '巴列维文（书体）',
        'Phnx' => '腓尼基文',
        'Plrd' => '波拉德音标文字',
        'Prti' => '帕提亚文碑铭体',
        'Qaag' => 'Zawgyi',
        'Rjng' => '拉让文',
        'Rohg' => '哈乃斐罗兴亚文',
        'Roro' => '朗格朗格文',
        'Runr' => '古代北欧文',
        'Samr' => '撒马利亚文',
        'Sara' => '沙拉堤文',
        'Sarb' => '古南阿拉伯文',
        'Saur' => '索拉什特拉文',
        'Sgnw' => '书写符号',
        'Shaw' => '萧伯纳式文',
        'Shrd' => '夏拉达文',
        'Sidd' => '悉昙',
        'Sind' => '信德文',
        'Sinh' => '僧伽罗文',
        'Sogd' => '粟特文',
        'Sogo' => '古粟特文',
        'Sora' => '索朗桑朋文',
        'Soyo' => '索永布文',
        'Sund' => '巽他文',
        'Sylo' => '锡尔赫特文',
        'Syrc' => '叙利亚文',
        'Syre' => '福音体叙利亚文',
        'Syrj' => '西叙利亚文',
        'Syrn' => '东叙利亚文',
        'Tagb' => '塔格班瓦文',
        'Takr' => '泰克里文',
        'Tale' => '泰乐文',
        'Talu' => '新傣文',
        'Taml' => '泰米尔文',
        'Tang' => '唐古特文',
        'Tavt' => '越南傣文',
        'Telu' => '泰卢固文',
        'Teng' => '腾格瓦文字',
        'Tfng' => '提非纳文',
        'Tglg' => '塔加路文',
        'Thaa' => '塔安那文',
        'Thai' => '泰文',
        'Tibt' => '藏文',
        'Tirh' => '迈蒂利文',
        'Ugar' => '乌加里特文',
        'Vaii' => '瓦依文',
        'Visp' => '可见语言',
        'Wara' => '瓦郎奇蒂文字',
        'Wcho' => '万秋文',
        'Wole' => '沃莱艾文',
        'Xpeo' => '古波斯文',
        'Xsux' => '苏美尔-阿卡德楔形文字',
        'Yezi' => '雅兹迪文',
        'Yiii' => '彝文',
        'Zanb' => '札那巴札尔方块文字',
        'Zinh' => '遗传学术语',
        'Zmth' => '数学符号',
        'Zsye' => '表情符号',
        'Zsym' => '符号',
        'Zxxx' => '非书面文字',
        'Zyyy' => '通用',
    ],
];

==> symfony_5.4.23+dfsg.orig.tar.xz: symfony-5.4.23/src/Symfony/Component/Intl/Resources/data/scripts/zh.php <==
<?php

return [
    'Names' => [
        'Adlm' => '阿德拉姆文',
        'Afak' => '阿法卡文',
        'Aghb' => '高加索阿尔巴尼亚文',
        'Ahom' => 'Ahom',
        'Arab' => '阿拉伯文',
        'Aran' => '波斯体',
        'Armi' => '皇室亚拉姆文',
        'Armn' => '亚美尼亚文',
        'Avst' => '阿维斯陀文',
        'Bali' => '巴厘文',
        'Bamu' => '巴姆穆文',
        'Bass' => '巴萨文',
        'Batk' => '巴塔克文',
        'Beng' => '孟加拉文',
        'Bhks' => '拜克舒克文',
        'Blis' => '布列斯符号',
        'Bopo' => '汉语拼音',
        'Brah' => '婆罗米文字',
        'Brai' => '布莱叶盲文',
        'Bugi' => '布吉文',
        'Buhd' => '布希德文',
        'Cakm' => '查克马文',
        'Cans' => '加拿大土著统一音节',
        'Cari' => '卡里亚文',
        'Cham' => '占文',
        'Cher' => '切罗基文',
        'Chrs' => '花拉子模文',
        'Cirt' => '色斯文',
        'Copt' => '克普特文',
        'Cpmn' => '塞浦路斯米诺斯文',
        'Cprt' => '塞浦路斯文',
        'Cyrl' => '西里尔文',
        'Cyrs' => '西里尔文字（古教会斯拉夫文的变体）',
        'Deva' => '天城文',
        'Diak' => '迪维西阿库鲁文',
        'Dogr' => '多格拉文',
        'Dsrt' => '德塞莱特文',
        'Dupl' => '杜普洛伊速记',
        'Egyd' => '后期埃及文',
        'Egyh' => '古埃及僧侣书写体',
        'Egyp' => '古埃及象形文',
        'Elba' => '爱尔巴桑文',
        'Elym' => '埃利迈文',
        'Ethi' => '埃塞俄比亚文',
        'Geok' => '格鲁吉亚文（教堂体）',
        'Geor' => '格鲁吉亚文',
        'Glag' => '格拉哥里文',
        'Gong' => '贡贾拉贡德文',
        'Gonm' => '马萨拉姆冈德文',
        'Goth' => '哥特文',
        'Gran' => '格兰塔文',
        'Grek' => '希腊文',
        'Gujr' => '古吉拉特文',
        'Guru' => '果鲁穆奇文',
        'Hanb' => '汉语注音',
        'Hang' => '谚文',
        'Hani' => '汉字',
        'Hano' => '汉奴罗文',
        'Hans' => '简体',
        'Hant' => '繁体',
        'Hatr' => '哈特兰文',
        'Hebr' => '希伯来文',
        'Hira' => '平假名',
        'Hluw' => '安那托利亚象形文字',
        'Hmng' => '杨松录苗文',
        'Hmnp' => '尼亚肯蒲丘苗文',
        'Hrkt' => '假名表',
        'Hung' => '古匈牙利文',
        'Inds' => '印度河文字',
        'Ital' => '古意大利文',
        'Jamo' => '韩文字母',
        'Java' => '爪哇文',
        'Jpan' => '日文',
        'Jurc' => '女真文',
        'Kali' => '克耶李文字',
        'Kana' => '片假名',
        'Kawi' => '卡维文',
        'Khar' => '卡罗须提文',
        'Khmr' => '高棉文',
        'Khoj' => '克吉奇文字',
        'Kits' => '契丹小字',
        'Knda' => '卡纳达文',
        'Kore' => '韩文',
        'Kpel' => '克佩列文',
        'Kthi' => '凯提文',
        'Lana' => '兰拿文',
        'Laoo' => '老挝文',
        'Latf' => '拉丁文（哥特式字体变体）',
        'Latg' => '拉丁文（盖尔文变体）',
        'Latn' => '拉丁文',
        'Lepc' => '雷布查文',
        'Limb' => '林布文',
        'Lina' => '线形文字（A）',
        'Linb' => '线形文字（B）',
        'Lisu' => '傈僳文',
        'Loma' => '洛马文',
        'Lyci' => '利西亚文',
        'Lydi' => '吕底亚文',
        'Mahj' => '默哈金文',
        'Maka' => '望加锡文',
        'Mand' => '阿拉米文',
        'Mani' => '摩尼教文',
        'Marc' => '大玛尔文',
        'Maya' => '玛雅圣符文',
        'Medf' => '梅德法伊德林文',
        'Mend' => '门迪文',
        'Merc' => '麦罗埃草书',
        'Mero' => '麦若提克文',
        'Mlym' => '马拉雅拉姆文',
        'Modi' => '莫迪文',
        'Mong' => '蒙古文',
        'Moon' => '穆恩字母',
        'Mroo' => '谬文',
        'Mtei' => '曼尼普尔文',
        'Mult' => '穆尔坦文',
        'Mymr' => '缅甸文',
        'Nand' => '楠迪梵文',
        'Narb' => '古北方阿拉伯文',
        'Nbat' => '纳巴泰文',
        'Newa' => '尼瓦文',
        'Nkgb' => '纳西格巴文',
        'Nkoo' => '西非书面文字（N’Ko）',
        'Nshu' => '女书',
        'Ogam' => '欧甘文',
        'Olck' => '桑塔利文',
        'Orkh' => '鄂尔浑文',
        'Orya' => '奥里亚文',
        'Osge' => '欧塞奇文',
        'Osma' => '奥斯曼亚文',
        'Ougr' => '回鹘文',
        'Palm' => '帕尔迈拉文',
        'Pauc' => '包金豪文',
        'Perm' => '古彼尔姆文',
        'Phag' => '八思巴文',
        'Phli' => '巴列维文碑铭体',
        'Phlp' => '巴列维文（圣诗体）',
        'Phlv' => '巴列维文（书体）',
        'Phnx' => '腓尼基文',
        'Plrd' => '波拉德音标文字',
        'Prti' => '帕提亚文碑铭体',
        'Qaag' => '照济文',
        'Rjng' => '拉让文',
        'Rohg' => '哈乃斐文',
        'Roro' => '朗格朗格文',
        'Runr' => '古代北欧文',
        'Samr' => '撒马利亚文',
        'Sara' => '沙拉堤文',
        'Sarb' => '古南阿拉伯文',
        'Saur' => '索拉什特拉文',
        'Sgnw' => '书写符号',
        'Shaw' => '萧伯纳式文',
        'Shrd' => '夏拉达文',
        'Sidd' => '悉昙文',
        'Sind' => '信德文',
        'Sinh' => '僧伽罗文',
        'Sogd' => '粟特文',
        'Sogo' => '古粟特文',
        'Sora' => '索朗桑朋文',
        'Soyo' => '索永布文',
        'Sund' => '巽他文',
        'Sylo' => '锡尔赫特文',
        'Syrc' => '叙利亚文',
        'Syre' => '福音体叙利亚文',
        'Syrj' => '西叙利亚文',
        'Syrn' => '东叙利亚文',
        'Tagb' => '塔格班瓦文',
        'Takr' => '泰克里文',
        'Tale' => '泰乐文',
        'Talu' => '新傣文',
        'Taml' => '泰米尔文',
        'Tang' => '唐古特文',
        'Tavt' => '越南傣文',
        'Telu' => '泰卢固文',
        'Teng' => '腾格瓦文字',
        'Tfng' => '提非纳文',
        'Tglg' => '塔加路文',
        'Thaa' => '塔安那文',
        'Thai' => '泰文',
        'Tibt' => '藏文',
        'Tirh' => '迈蒂利文',
        'Tnsa' => '坦萨文',
        'Toto' => '投投文',
        'Ugar' => '乌加里特文',
        'Vaii' => '瓦依文',
        'Visp' => '可见语言',
        'Wara' => '瓦郎奇蒂文字',
        'Wcho' => '万秋文',
        'Wole' => '沃莱艾文',
        'Xpeo' => '古波斯文',
        'Xsux' => '苏美尔-阿卡德楔形文字',
        'Yezi' => '雅兹迪文',
        'Yiii' => '彝文',
        'Zanb' => '札那巴札尔方块文字',
        'Zinh' => '遗传学术语',
        'Zmth' => '数学符号',
        'Zsye' => '表情符号',
        'Zsym' => '符号',
        'Zxxx' => '非书面文字',
        'Zyyy' => '通用',
    ],
];
